import 'babel-polyfill';

var main = new WeakMap();

export { main as default };
